@@ -6,3 +6,5 @@ to take math blocks(m{10+10}) and evaluate them down to their result.
 from .math import MathEvaluationFilter
 from .random import RandomFilter
 from .variable import VariableFilter
+from .optional import OptionalFilter
+from .strf import STRFFilter
