@@ -124,6 +124,9 @@ class MathEvaluationFilter():
         output = text
         for match in REGEX.finditer(text):
             math_value = NSP.eval(match.group(0).lstrip("m{").rstrip("}"))
-            output = output.replace(match.group(0), str(math_value))
+            if math_value.is_integer():
+                output = output.replace(match.group(0), str(int(math_value)))
+            else:
+                output = output.replace(match.group(0), str(math_value))
 
         return output
